package com.yiqi.activity.mapper;

import java.util.Date;
import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.yiqi.activity.domain.vo.ActivityClothItemMinPriceVO;
import com.yiqi.activity.domain.vo.ActivityClothItemVO;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.activity.domain.ActivityClothItem;
import org.apache.ibatis.annotations.Param;

/**
 * 指定衣服折扣活动明细Mapper接口
 *
 * @author xiaohei
 * @date 2023-09-11
 */
@Mapper
public interface ActivityClothItemMapper extends BaseMapper<ActivityClothItem> {
    /**
     * 查询指定衣服折扣活动明细
     *
     * @param id 指定衣服折扣活动明细主键
     * @return 指定衣服折扣活动明细
     */
    public ActivityClothItem selectActivityClothItemById(Long id);

    /**
     * 查询指定衣服折扣活动明细列表
     *
     * @param activityClothItem 指定衣服折扣活动明细
     * @return 指定衣服折扣活动明细集合
     */
    public List<ActivityClothItemVO> selectActivityClothItemList(ActivityClothItem activityClothItem);

    /**
     * 新增指定衣服折扣活动明细
     *
     * @param activityClothItem 指定衣服折扣活动明细
     * @return 结果
     */
    public int insertActivityClothItem(ActivityClothItem activityClothItem);

    /**
     * 修改指定衣服折扣活动明细
     *
     * @param activityClothItem 指定衣服折扣活动明细
     * @return 结果
     */
    public int updateActivityClothItem(ActivityClothItem activityClothItem);

    /**
     * 删除指定衣服折扣活动明细
     *
     * @param id 指定衣服折扣活动明细主键
     * @return 结果
     */
    public int deleteActivityClothItemById(Long id);

    /**
     * 批量删除指定衣服折扣活动明细
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteActivityClothItemByIds(Long[] ids);

    public  List<ActivityClothItemMinPriceVO> getMinPriceByActivity(@Param("nowTime") String nowTime,
                                                                    @Param("orgId") Long orgId,
                                                                    @Param("sourceType") String sourceType);

    public  List<ActivityClothItemMinPriceVO> getMinPriceWith1ClothItemByActivity(@Param("clothId")Long clothId,
                                                                                  @Param("nowTime") String nowTime,
                                                                                  @Param("orgId") Long orgId,
                                                                                  @Param("sourceType") String sourceType);
}
